==> deltafi-common-0.100.0-sources.jar: org/deltafi/common/types/ActionEventInput.java <==
/**
 *    DeltaFi - Data transformation and enrichment platform
 *
 *    Copyright 2021-2023 DeltaFi Contributors <deltafi@deltafi.org>
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 */
package org.deltafi.common.types;

import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.time.OffsetDateTime;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.util.stream.Collectors;

@Data
@NoArgsConstructor
@AllArgsConstructor
@Builder(builderMethodName = "newBuilder")
public class ActionEventInput {
  private String did;
  private String action;
  private OffsetDateTime start;
  private OffsetDateTime stop;
  private OffsetDateTime time;
  private ActionEventType type;
  private DomainEvent domain;
  private TransformEvent transform;
  private LoadEvent load;
  private EnrichEvent enrich;
  private FormatEvent format;
  private List<FormatEvent> formatMany;
  private ErrorEvent error;
  private FilterEvent filter;
  private List<SplitEvent> split;
  private List<Metric> metrics;
}

==> deltafi-common-0.102.0-sources.jar: org/deltafi/common/types/ActionEventInput.java <==
/*
 *    DeltaFi - Data transformation and enrichment platform
 *
 *    Copyright 2021-2023 DeltaFi Contributors <deltafi@deltafi.org>
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 */
package org.deltafi.common.types;

import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.time.OffsetDateTime;
import java.util.List;

@Data
@NoArgsConstructor
@AllArgsConstructor
@Builder(builderMethodName = "newBuilder")
public class ActionEventInput {
  private String did;
  private String action;
  private OffsetDateTime start;
  private OffsetDateTime stop;
  private OffsetDateTime time;
  private ActionEventType type;
  private DomainEvent domain;
  private TransformEvent transform;
  private LoadEvent load;
  private List<LoadEvent> loadMany;
  private EnrichEvent enrich;
  private FormatEvent format;
  private List<FormatEvent> formatMany;
  private ErrorEvent error;
  private FilterEvent filter;
  private List<SplitEvent> split;
  private JoinEvent join;
  private List<Metric> metrics;
}
